@@ -1,4 +1,5 @@
 import datetime
+import json
 import re
 import typing
 from typing import List
@@ -97,15 +98,8 @@ class SouthernCompanyAPI:
 
     async def _get_sc_web_token(self) -> str:
         """Gets a sc_web_token which we get from a successful log in"""
-        # update to use property
-        if (
-            self._request_token is None
-            or datetime.datetime.now() >= self._request_token_expiry
-        ):
-            self._request_token = await get_request_verification_token()
-            self._request_token_expiry = datetime.datetime.now() + datetime.timedelta(
-                hours=3
-            )
+        if await self.request_token is None:
+            raise CantReachSouthernCompany("Request Token could not be refreshed")
         headers = {
             "Content-Type": "application/json; charset=utf-8",
             "RequestVerificationToken": self._request_token,
@@ -126,7 +120,7 @@ class SouthernCompanyAPI:
                     raise CantReachSouthernCompany()
                 try:
                     connection = await response.json()
-                except ContentTypeError as err:
+                except (ContentTypeError, json.JSONDecodeError) as err:
                     raise InvalidLogin from err
                 if connection["statusCode"] == 500:
                     raise InvalidLogin()
@@ -143,8 +137,8 @@ class SouthernCompanyAPI:
 
     async def _get_southern_jwt_cookie(self) -> str:
         # update to use property
-        if self._sc is None or datetime.datetime.now() >= self._sc_expiry:
-            self._sc = await self._get_sc_web_token()
+        if await self.sc is None:
+            raise CantReachSouthernCompany("Sc token cannot be refreshed")
         data = {"ScWebToken": self._sc}
         async with aiohttp.ClientSession() as session:
             async with session.post(
@@ -237,7 +231,16 @@ class SouthernCompanyAPI:
             ) as resp:
                 if resp.status != 200:
                     raise AccountFailure("failed to get accounts")
-                account_json = await resp.json()
+                try:
+                    account_json = await resp.json()
+                except (ContentTypeError, json.JSONDecodeError) as err:
+                    try:
+                        error_text = await resp.text()
+                    except aiohttp.ClientError:
+                        error_text = err.msg
+                    raise CantReachSouthernCompany(
+                        f"Incorrect mimetype while trying to get accounts. {error_text}"
+                    ) from err
                 accounts = []
                 for account in account_json["Data"]:
                     accounts.append(
